@@ -1,7 +1,8 @@
 # Copyright 2017-2020 Palantir Technologies, Inc.
 # Copyright 2021- Python Language Server Contributors.
 
-""" py.test configuration"""
+"""pytest configuration"""
+
 import logging
 
 from pylsp.__main__ import LOG_FORMAT
