@@ -6,9 +6,8 @@ import os
 import pytest
 
 from pylsp import uris
-from pylsp.workspace import Document
 from pylsp.plugins.references import pylsp_references
-
+from pylsp.workspace import Document
 
 DOC1_NAME = "test1.py"
 DOC2_NAME = "test2.py"
@@ -36,7 +35,7 @@ def tmp_workspace(temp_workspace_factory):
     )
 
 
-def test_references(tmp_workspace):  # pylint: disable=redefined-outer-name
+def test_references(tmp_workspace) -> None:
     # Over 'Test1' in class Test1():
     position = {"line": 0, "character": 8}
     DOC1_URI = uris.from_fs_path(os.path.join(tmp_workspace.root_path, DOC1_NAME))
@@ -66,7 +65,7 @@ def test_references(tmp_workspace):  # pylint: disable=redefined-outer-name
     assert doc2_usage_ref["range"]["end"] == {"line": 3, "character": 9}
 
 
-def test_references_builtin(tmp_workspace):  # pylint: disable=redefined-outer-name
+def test_references_builtin(tmp_workspace) -> None:
     # Over 'UnicodeError':
     position = {"line": 4, "character": 7}
     doc2_uri = uris.from_fs_path(os.path.join(str(tmp_workspace.root_path), DOC2_NAME))
